@@ -74,6 +74,9 @@ pub enum FfiError {
 
     /// Ownership error.
     OwnershipError,
+
+    /// Caught a panic (which would be UB if we let it unwind across the FFI).
+    UnexpectedPanic,
 }
 
 impl FfiError {
@@ -95,3 +98,13 @@ impl From<FfiError> for FfiOckamError {
         Self::from(err)
     }
 }
+
+/// # Safety
+/// frees `FfiOckamError::domain` if it's non-null
+#[no_mangle]
+pub unsafe extern "C" fn ockam_vault_free_error(context: &mut FfiOckamError) {
+    if !context.domain.is_null() {
+        let _ = CString::from_raw(context.domain as *mut _);
+        context.domain = core::ptr::null();
+    }
+}
